/*
 *  GeoTIFF Rev. 0.2  Ellipsoids
 */

/* C database for Geotiff include files.   */
/* the macro ValuePair() must be defined   */
/* by the enclosing include file           */

#ifdef INCLUDE_OLD_CODES
#include old_ellipse.inc
#endif /* OLD Codes */

ValuePair(Ellipse_Airy_1830,	7001)
ValuePair(Ellipse_Airy_Modified_1849,	7002)
ValuePair(Ellipse_Australian_National_Spheroid,	7003)
ValuePair(Ellipse_Bessel_1841,	7004)
ValuePair(Ellipse_Bessel_Modified,	7005)
ValuePair(Ellipse_Bessel_Namibia,	7006)
ValuePair(Ellipse_Clarke_1858,	7007)
ValuePair(Ellipse_Clarke_1866,	7008)
ValuePair(Ellipse_Clarke_1866_Michigan,	7009)
ValuePair(Ellipse_Clarke_1880_Benoit,	7010)
ValuePair(Ellipse_Clarke_1880_IGN,	7011)
ValuePair(Ellipse_Clarke_1880_RGS,	7012)
ValuePair(Ellipse_Clarke_1880_Arc,	7013)
ValuePair(Ellipse_Clarke_1880_SGA_1922,	7014)
ValuePair(Ellipse_Everest_1830_1937_Adjustment,	7015)
ValuePair(Ellipse_Everest_1830_1967_Definition,	7016)
ValuePair(Ellipse_Everest_1830_1975_Definition,	7017)
ValuePair(Ellipse_Everest_1830_Modified,	7018)
ValuePair(Ellipse_GRS_1980,	7019)
ValuePair(Ellipse_Helmert_1906,	7020)
ValuePair(Ellipse_Indonesian_National_Spheroid,	7021)
ValuePair(Ellipse_International_1924,	7022)
ValuePair(Ellipse_International_1967,	7023)
ValuePair(Ellipse_Krassowsky_1940,	7024)
ValuePair(Ellipse_NWL_9D,	7025)
ValuePair(Ellipse_NWL_10D,	7026)
ValuePair(Ellipse_Plessis_1817,	7027)
ValuePair(Ellipse_Struve_1860,	7028)
ValuePair(Ellipse_War_Office,	7029)
ValuePair(Ellipse_WGS_84,	7030)
ValuePair(Ellipse_GEM_10C,	7031)
ValuePair(Ellipse_OSU86F,	7032)
ValuePair(Ellipse_OSU91A,	7033)
ValuePair(Ellipse_Clarke_1880,	7034)
ValuePair(Ellipse_Sphere,	7035)
/* end of list */
